@@ -6,13 +6,14 @@
 
 #include <errno.h>
 
-#ifndef HAVE_ERRNO_DECL
+#if !HAVE_DECL_ERRNO
 extern int errno;
 #endif
 
-int revoke (path)
-     char *path;
+int
+revoke (char *path)
 {
+	(void)path;
 #ifdef ENOSYS
   errno = ENOSYS;
 #else
