@@ -1,24 +1,32 @@
 
 /*
    Unix snprintf implementation.
-   Version 1.1
-   
+   Version 1.3
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+   It can be redistribute also under the terms of GNU Library General
+   Public Lincense.
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-   
+
    Revision History:
 
+   1.3:
+      *  add #include <config.h> ifdef HAVE_CONFIG_H
+      *  cosmetic change, when exponent is 0 print xxxE+00
+         instead of xxxE-00
+   1.2:
+      *  put the program under LGPL.
    1.1:
       *  added changes from Miles Bader
       *  corrected a bug with %f
@@ -36,9 +44,6 @@
      Mike Parker(mouse)
 
 */
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
 
 #include "snprintf.h"
 
@@ -52,7 +57,7 @@ pow_10(int n)
 pow_10(n)
 int n;
 #endif
-{ 
+{
   int i;
   double P;
 
@@ -64,7 +69,7 @@ int n;
 }
 
 /*
- * Find the integral part of the log in base 10 
+ * Find the integral part of the log in base 10
  * Note: this not a real log10()
          I just need and approximation(integerpart) of x in:
           10^x ~= r
@@ -78,7 +83,7 @@ log_10(double r)
 log_10(r)
 double r;
 #endif
-{ 
+{
   int i = 0;
   double result = 1.;
 
@@ -107,7 +112,7 @@ integral(real, ip)
 double real;
 double * ip;
 #endif
-{ 
+{
   int j;
   double i, s, p;
   double real_integral = 0.;
@@ -141,11 +146,11 @@ double * ip;
 }
 
 #define PRECISION 1.e-6
-/* 
+/*
  * return an ascii representation of the integral part of the number
  * and set fract to be an ascii representation of the fraction part
  * the container for the fraction and the integral part or staticly
- * declare with fix size 
+ * declare with fix size
  */
 PRIVATE char *
 #ifdef __STDC__
@@ -168,7 +173,7 @@ char ** fract;
   int ch;
 
 /* taking care of the obvious case: 0.0 */
-  if (number == 0.) { 
+  if (number == 0.) {
     integral_part[0] = '0';
     integral_part[1] = '\0';
     fraction_part[0] = '0';
@@ -180,7 +185,7 @@ char ** fract;
   if ((sign = number) < 0.) {
     number = -number;
     digits--; /* sign consume one digit */
-  } 
+  }
 
   fraction = integral(number, &ip);
   number = ip;
@@ -195,11 +200,11 @@ char ** fract;
       ch = (int)((fp + PRECISION)*base); /* force to round */
       integral_part[i] = (ch <= 9) ? ch + '0' : ch + 'a' - 10;
       if (! isxdigit(integral_part[i])) /* bail out overflow !! */
-        break; 
+        break;
       number = ip;
      }
   }
-     
+
 /* Oh No !! out of bound, ho well fill it up ! */
   if (number != 0.)
     for (i = 0; i < digits; ++i)
@@ -213,7 +218,7 @@ char ** fract;
 
 /* reverse every thing */
   for ( i--, j = 0; j < i; j++, i--)
-    SWAP_INT(integral_part[i], integral_part[j]);  
+    SWAP_INT(integral_part[i], integral_part[j]);
 
 /* the fractionnal part */
   for (i=0, fp=fraction; precision > 0 && i < MAX_FRACT ; i++, precision--	) {
@@ -351,7 +356,7 @@ double d;
             ((d > 0. && p->justify == RIGHT) ? 1:0) -
             ((p->space == FOUND) ? 1:0) -
             strlen(tmp) - p->precision - 1;
-  PAD_RIGHT(p);  
+  PAD_RIGHT(p);
   PUT_PLUS(d, p);
   PUT_SPACE(d, p);
   while (*tmp) { /* the integral */
@@ -362,12 +367,12 @@ double d;
     PUT_CHAR('.', p);  /* put the '.' */
   if (*p->pf == 'g' || *p->pf == 'G') /* smash the trailing zeros */
     for (i = strlen(tmp2) - 1; i >= 0 && tmp2[i] == '0'; i--)
-       tmp2[i] = '\0'; 
+       tmp2[i] = '\0';
   for (; *tmp2; tmp2++)
     PUT_CHAR(*tmp2, p); /* the fraction */
-  
+
   PAD_LEFT(p);
-} 
+}
 
 /* %e %E %g exponent representation */
 PRIVATE void
@@ -385,12 +390,12 @@ double d;
   DEF_PREC(p);
   j = log_10(d);
   d = d / pow_10(j);  /* get the Mantissa */
-  d = ROUND(d, p);                  
+  d = ROUND(d, p);
   tmp = dtoa(d, p->precision, &tmp2);
   /* 1 for unit, 1 for the '.', 1 for 'e|E',
    * 1 for '+|-', 3 for 'exp' */
   /* calculate how much padding need */
-  p->width = p->width - 
+  p->width = p->width -
              ((d > 0. && p->justify == RIGHT) ? 1:0) -
              ((p->space == FOUND) ? 1:0) - p->precision - 7;
   PAD_RIGHT(p);
@@ -404,30 +409,30 @@ double d;
     PUT_CHAR('.', p);  /* the '.' */
   if (*p->pf == 'g' || *p->pf == 'G') /* smash the trailing zeros */
     for (i = strlen(tmp2) - 1; i >= 0 && tmp2[i] == '0'; i--)
-       tmp2[i] = '\0'; 
+       tmp2[i] = '\0';
   for (; *tmp2; tmp2++)
     PUT_CHAR(*tmp2, p); /* the fraction */
 
   if (*p->pf == 'g' || *p->pf == 'e') { /* the exponent put the 'e|E' */
-     PUT_CHAR('e', p);
-   } else
-     PUT_CHAR('E', p);
-   if (j > 0) {  /* the sign of the exp */
-     PUT_CHAR('+', p);
-   } else {
-     PUT_CHAR('-', p);
-     j = -j;
-   }
-   tmp = itoa((double)j);
-   if (j < 9) {  /* need to pad the exponent with 0 '000' */
-     PUT_CHAR('0', p); PUT_CHAR('0', p);
-   } else if (j < 99)
-     PUT_CHAR('0', p);
-   while (*tmp) { /* the exponent */
-     PUT_CHAR(*tmp, p);
-     tmp++;
-   }
-   PAD_LEFT(p);
+    PUT_CHAR('e', p);
+  } else
+    PUT_CHAR('E', p);
+  if (j >= 0) {  /* the sign of the exp */
+    PUT_CHAR('+', p);
+  } else {
+    PUT_CHAR('-', p);
+    j = -j;
+  }
+  tmp = itoa((double)j);
+  if (j < 9) {  /* need to pad the exponent with 0 '000' */
+    PUT_CHAR('0', p); PUT_CHAR('0', p);
+  } else if (j < 99)
+    PUT_CHAR('0', p);
+  while (*tmp) { /* the exponent */
+    PUT_CHAR(*tmp, p);
+    tmp++;
+  }
+  PAD_LEFT(p);
 }
 
 /* initialize the conversion specifiers */
@@ -467,7 +472,7 @@ struct DATA * p;
       case '1': case '2': case '3':
       case '4': case '5': case '6':
       case '7': case '8': case '9':     /* gob all the digits */
-        for (i = 0; isdigit(*s); i++, s++) 
+        for (i = 0; isdigit(*s); i++, s++)
           if (i < MAX_FIELD/2 - 1)
             number[i] = *s;
         number[i] = '\0';
@@ -521,10 +526,10 @@ va_list args;
           case 'f':  /* float, double */
             STAR_ARGS(&data);
             d = va_arg(args, double);
-            floating(&data, d);  
+            floating(&data, d);
             state = 0;
             break;
-          case 'g': 
+          case 'g':
           case 'G':
             STAR_ARGS(&data);
             DEF_PREC(&data);
@@ -548,7 +553,15 @@ va_list args;
             exponent(&data, d);
             state = 0;
             break;
-          case 'u':
+	  case 'u':  /* unsigned decimal */
+	    STAR_ARGS(&data);
+	    if (data.a_long == FOUND)
+		d = va_arg(args, unsigned long);
+	    else
+		d = va_arg(args, unsigned int);
+	    decimal(&data, d);
+	    state = 0;
+	    break;
           case 'd':  /* decimal */
             STAR_ARGS(&data);
             if (data.a_long == FOUND)
@@ -567,7 +580,7 @@ va_list args;
             octal(&data, d);
             state = 0;
             break;
-          case 'x': 
+          case 'x':
           case 'X':  /* hexadecimal */
             STAR_ARGS(&data);
             if (data.a_long == FOUND)
@@ -601,11 +614,11 @@ va_list args;
             state = 0;
             break;
           case '#': case ' ': case '+': case '*':
-          case '-': case '.': case '0': case '1': 
+          case '-': case '.': case '0': case '1':
           case '2': case '3': case '4': case '5':
           case '6': case '7': case '8': case '9':
            /* initialize width and precision */
-            for (i = 0; isflag(*data.pf); i++, data.pf++) 
+            for (i = 0; isflag(*data.pf); i++, data.pf++)
               if (i < MAX_FIELD - 1)
                 conv_field[i] = *data.pf;
             conv_field[i] = '\0';
@@ -797,7 +810,7 @@ void main()
   printf("abc%n", &i); printf("%d\n", i);
   snprintf(holder, sizeof holder, "abc%n", &i);
   printf("%s", holder); printf("%d\n\n", i);
-  
+
   printf("%%*.*s --> 10.10\n");
   snprintf(holder, sizeof holder, "%*.*s\n", 10, 10, BLURB);
   printf("%*.*s\n", 10, 10, BLURB);
@@ -810,7 +823,7 @@ void main()
 
 #define BIG "Hello this is a too big string for the buffer"
 /*  printf("A buffer to small of 10, trying to put this:\n");*/
-  printf("<%%>, %s\n", BIG); 
+  printf("<%%>, %s\n", BIG);
   i = snprintf(holder, 10, "%s\n", BIG);
   printf("<%s>\n", BIG);
   printf("<%s>\n", holder);
