@@ -1,7 +1,6 @@
 /* Return an error saying we couldn't find any termcap database.  */
 int
-tgetent (buf, type)
-     char *buf, *type;
+tgetent (char *buf, int *type)
 {
   return -1;
 }
