@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -50,8 +46,8 @@ static char sccsid[] = "@(#)get_addrs.c	8.1 (Berkeley) 6/6/93";
 #include <stdio.h>
 #include "talk_ctl.h"
 
-get_addrs(my_machine_name, his_machine_name)
-	char *my_machine_name, *his_machine_name;
+int
+get_addrs(char *my_machine_name, char *his_machine_name)
 {
 	struct hostent *hp;
 	struct servent *sp;
