@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -56,9 +52,8 @@ extern	CTL_MSG msg;
 /*
  * Determine the local and remote user, tty, and machines
  */
-get_names(argc, argv)
-	int argc;
-	char *argv[];
+int
+get_names(int argc, char *argv[])
 {
 	extern char *localhost ();
 	char *his_name, *my_name;
