@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -126,7 +122,7 @@ extern struct termio new_tc;
 static fd_set ibits, obits, xbits;
 
 
-    void
+void
 init_sys()
 {
     tout = fileno(stdout);
@@ -139,18 +135,14 @@ init_sys()
 }
 
 
-    int
-TerminalWrite(buf, n)
-    char *buf;
-    int  n;
+int
+TerminalWrite(char *buf, int  n)
 {
     return write(tout, buf, n);
 }
 
-    int
-TerminalRead(buf, n)
-    char *buf;
-    int  n;
+int
+TerminalRead(char *buf, int  n)
 {
     return read(tin, buf, n);
 }
@@ -159,7 +151,7 @@ TerminalRead(buf, n)
  *
  */
 
-    int
+int
 TerminalAutoFlush()
 {
 #if	defined(LNOFLSH)
@@ -189,9 +181,8 @@ extern int kludgelinemode;
 
 extern void xmitAO(), xmitEL(), xmitEC(), intp(), sendbrk();
 
-    int
-TerminalSpecialChars(c)
-    int	c;
+int
+TerminalSpecialChars(int c)
 {
     if (c == termIntChar) {
 	intp();
@@ -232,18 +223,19 @@ TerminalSpecialChars(c)
 /*
  * Flush output to the terminal
  */
- 
-    void
+
+void
 TerminalFlushOutput()
 {
+    int flags = 0;
 #ifdef	TIOCFLUSH
-    (void) ioctl(fileno(stdout), TIOCFLUSH, (char *) 0);
+    (void) ioctl(fileno(stdout), TIOCFLUSH, &flags);
 #else
-    (void) ioctl(fileno(stdout), TCFLSH, (char *) 0);
+    (void) ioctl(fileno(stdout), TCFLSH, &flags);
 #endif
 }
 
-    void
+void
 TerminalSaveState()
 {
 #ifndef	USE_TERMIO
@@ -285,9 +277,8 @@ TerminalSaveState()
 #endif	/* USE_TERMIO */
 }
 
-    cc_t *
-tcval(func)
-    register int func;
+cc_t *
+tcval(register int func)
 {
     switch(func) {
     case SLC_IP:	return(&termIntChar);
@@ -328,7 +319,7 @@ tcval(func)
     }
 }
 
-    void
+void
 TerminalDefaultChars()
 {
 #ifndef	USE_TERMIO
@@ -392,9 +383,8 @@ TerminalRestoreState()
  */
 
 
-    void
-TerminalNewMode(f)
-    register int f;
+void
+TerminalNewMode(register int f)
 {
     static int prevmode = 0;
 #ifndef	USE_TERMIO
@@ -691,7 +681,7 @@ TerminalNewMode(f)
 	  sigaddset(&sigs, SIGTSTP);
 	  sigprocmask(SIG_UNBLOCK, &sigs, 0);
 	}
-# else	
+# else
 	(void) sigsetmask(sigblock(0) & ~(1<<(SIGTSTP-1)));
 # endif /* HAVE_SIGACTION */
 #endif	/* SIGTSTP */
@@ -793,10 +783,8 @@ struct termspeeds {
 };
 #endif	/* DECODE_BAUD */
 
-    void
-TerminalSpeeds(ispeed, ospeed)
-    long *ispeed;
-    long *ospeed;
+void
+TerminalSpeeds(long *ispeed, long *ospeed)
 {
 #ifdef	DECODE_BAUD
     register struct termspeeds *tp;
@@ -824,9 +812,8 @@ TerminalSpeeds(ispeed, ospeed)
 #endif	/* DECODE_BAUD */
 }
 
-    int
-TerminalWindowSize(rows, cols)
-    long *rows, *cols;
+int
+TerminalWindowSize(long *rows, long *cols)
 {
 #ifdef	TIOCGWINSZ
     struct winsize ws;
@@ -840,34 +827,28 @@ TerminalWindowSize(rows, cols)
     return 0;
 }
 
-    int
-NetClose(fd)
-    int	fd;
+int
+NetClose(int fd)
 {
     return close(fd);
 }
 
 
-    void
-NetNonblockingIO(fd, onoff)
-    int fd;
-    int onoff;
+void
+NetNonblockingIO(int fd, int onoff)
 {
     ioctl(fd, FIONBIO, (char *)&onoff);
 }
 
 #if	defined(TN3270)
-    void
-NetSigIO(fd, onoff)
-    int fd;
-    int onoff;
+void
+NetSigIO(int fd, int onoff)
 {
     ioctl(fd, FIOASYNC, (char *)&onoff);	/* hear about input */
 }
 
-    void
-NetSetPgrp(fd)
-    int fd;
+void
+NetSetPgrp(int fd)
 {
     int myPid;
 
@@ -881,18 +862,16 @@ NetSetPgrp(fd)
  */
 
     /* ARGSUSED */
-    RETSIGTYPE
-deadpeer(sig)
-    int sig;
+RETSIGTYPE
+deadpeer(int sig)
 {
 	setcommandmode();
 	longjmp(peerdied, -1);
 }
 
     /* ARGSUSED */
-    RETSIGTYPE
-intr(sig)
-    int sig;
+RETSIGTYPE
+intr(int sig)
 {
     if (localchars) {
 	intp();
@@ -903,9 +882,8 @@ intr(sig)
 }
 
     /* ARGSUSED */
-    RETSIGTYPE
-intr2(sig)
-    int sig;
+RETSIGTYPE
+intr2(int sig)
 {
     if (localchars) {
 #ifdef	KLUDGELINEMODE
@@ -920,9 +898,8 @@ intr2(sig)
 
 #ifdef	SIGTSTP
     /* ARGSUSED */
-    RETSIGTYPE
-susp(sig)
-    int sig;
+RETSIGTYPE
+susp(int sig)
 {
     if ((rlogin != _POSIX_VDISABLE) && rlogin_susp())
 	return;
@@ -933,9 +910,8 @@ susp(sig)
 
 #ifdef	SIGWINCH
     /* ARGSUSED */
-    RETSIGTYPE
-sendwin(sig)
-    int sig;
+RETSIGTYPE
+sendwin(int sig)
 {
     if (connected) {
 	sendnaws();
@@ -945,9 +921,8 @@ sendwin(sig)
 
 #ifdef	SIGINFO
     /* ARGSUSED */
-    RETSIGTYPE
-ayt(sig)
-    int sig;
+RETSIGTYPE
+ayt(int sig)
 {
     if (connected)
 	sendayt();
@@ -957,7 +932,7 @@ ayt(sig)
 #endif
 
 
-    void
+void
 sys_telnet_init()
 {
     (void) signal(SIGINT, intr);
@@ -1002,9 +977,9 @@ sys_telnet_init()
  *	The return value is 1 if something happened, 0 if not.
  */
 
-    int
-process_rings(netin, netout, netex, ttyin, ttyout, poll)
-    int poll;		/* If 0, then block until something to do */
+/* poll; If 0, then block until something to do */
+int
+process_rings(int netin, int netout, int netex, int ttyin, int ttyout, int poll)
 {
     register int c;
 		/* One wants to be a bit careful about setting returnValue
@@ -1017,7 +992,7 @@ process_rings(netin, netout, netex, ttyin, ttyout, poll)
 
     if (netout) {
 	FD_SET(net, &obits);
-    } 
+    }
     if (ttyout) {
 	FD_SET(tout, &obits);
     }
