@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -76,9 +72,8 @@ int	prettydump;
  *	Upcase (in place) the argument.
  */
 
-    void
-upcase(argument)
-    register char *argument;
+void
+upcase(register char *argument)
 {
     register int c;
 
@@ -96,9 +91,8 @@ upcase(argument)
  * Compensate for differences in 4.2 and 4.3 systems.
  */
 
-    int
-SetSockOpt(fd, level, option, yesno)
-    int fd, level, option, yesno;
+int
+SetSockOpt(int fd, int level, int option, int yesno)
 {
 #ifndef	NOT43
     return setsockopt(fd, level, option,
@@ -119,9 +113,8 @@ SetSockOpt(fd, level, option, yesno)
 
 unsigned char NetTraceFile[256] = "(standard output)";
 
-    void
-SetNetTrace(file)
-    register char *file;
+void
+SetNetTrace(register char *file)
 {
     if (NetTrace && NetTrace != stdout)
 	fclose(NetTrace);
@@ -137,11 +130,8 @@ SetNetTrace(file)
     strcpy((char *)NetTraceFile, "(standard output)");
 }
 
-    void
-Dump(direction, buffer, length)
-    char direction;
-    unsigned char *buffer;
-    int length;
+void
+Dump(char direction, unsigned char *buffer, int length)
 {
 #   define BYTES_PER_LINE	32
 #   define min(x,y)	((x<y)? x:y)
@@ -189,10 +179,8 @@ Dump(direction, buffer, length)
 }
 
 
-	void
-printoption(direction, cmd, option)
-	char *direction;
-	int cmd, option;
+void
+printoption(char *direction, int cmd, int option)
 {
 	if (!showoptions)
 		return;
@@ -225,7 +213,7 @@ printoption(direction, cmd, option)
 	return;
 }
 
-    void
+void
 optionstatus()
 {
     register int i;
@@ -302,11 +290,11 @@ optionstatus()
 
 }
 
-    void
-printsub(direction, pointer, length)
-    char direction;	/* '<' or '>' */
-    unsigned char *pointer;	/* where suboption data sits */
-    int		  length;	/* length of suboption data */
+/* char direction; '<' or '>' */
+/* unsigned char *pointer; where suboption data sits */
+/* int		  length; length of suboption data */
+void
+printsub(char direction, unsigned char *pointer, int length)
 {
     register int i;
     char buf[512];
@@ -606,7 +594,7 @@ printsub(direction, pointer, length)
 		    break;
 		}
 		break;
-		
+
 	    case LM_SLC:
 		fprintf(NetTrace, "SLC");
 		for (i = 2; i < length - 2; i += 3) {
@@ -738,7 +726,7 @@ printsub(direction, pointer, length)
 			    fprintf(NetTrace, "\n");
 
 			break;
-				
+
 		    default:
 			fprintf(NetTrace, " %d", pointer[i]);
 			break;
@@ -879,7 +867,7 @@ printsub(direction, pointer, length)
  *			way to the kernel (thus the select).
  */
 
-    void
+void
 EmptyTerminal()
 {
 #if	defined(unix)
@@ -906,7 +894,7 @@ EmptyTerminal()
     }
 }
 
-    void
+void
 SetForExit()
 {
     setconnmode(0);
@@ -933,18 +921,15 @@ SetForExit()
     setcommandmode();
 }
 
-    void
-Exit(returnCode)
-    int returnCode;
+void
+Exit(int returnCode)
 {
     SetForExit();
     exit(returnCode);
 }
 
-    void
-ExitString(string, returnCode)
-    char *string;
-    int returnCode;
+void
+ExitString(char *string, int returnCode)
 {
     SetForExit();
     fwrite(string, 1, strlen(string), stderr);
